..
    Copyright (C) 2020-2021 Graz University of Technology.

    invenio-config-iform is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

=======================
 invenio-config-iform
=======================

.. image:: https://github.com/Cian-H/invenio-config-iform/workflows/CI/badge.svg
        :target: https://github.com/Cian-H/invenio-config-iform/actions

.. image:: https://img.shields.io/pypi/dm/invenio-config-iform.svg
        :target: https://pypi.python.org/pypi/invenio-config-iform

.. image:: https://img.shields.io/github/tag/Cian-H/invenio-config-iform.svg
        :target: https://github.com/Cian-H/invenio-config-iform/releases

.. image:: https://img.shields.io/github/license/Cian-H/invenio-config-iform.svg
        :target: https://github.com/Cian-H/invenio-config-iform/blob/master/LICENSE

.. image:: https://readthedocs.org/projects/invenio-config-iform/badge/?version=latest
        :target: https://invenio-config-iform.readthedocs.io/en/latest/?badge=latest

.. image:: https://img.shields.io/coveralls/mb-wali/invenio-config-iform.svg
        :target: https://coveralls.io/r/mb-wali/invenio-config-iform

.. image:: https://img.shields.io/badge/code%20style-Ruff-D7FF64.svg
    :target: https://github.com/astral-sh/ruff

invenio module that adds I-Form configs.

Override configs from invenio modules with I-Form configurations:

* Invenio-App
* Invenio-Mail
* Invenio-shibboleth
* Invenio-accounts
* Flask-security
* Defined routes for I-Form

Further documentation is available on
https://invenio-config-iform.readthedocs.io/

Forked from https://github.com/tu-graz-library/invenio-config-tugraz
